#
# spec file for package mediainfo
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2007-2011 The Packman Team
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mediainfo
Version:        20.08
Release:        lp152.4.3.1
Summary:        Audio/video file technical and tag information utility
License:        GPL-2.0-or-later
URL:            https://mediaarea.net
Source0:        https://mediaarea.net/download/source/%{name}/%{version}/%{name}_%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  kf5-filesystem
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel >= 3
BuildRequires:  pkgconfig(libmediainfo) = %{version}
BuildRequires:  pkgconfig(libzen)
BuildRequires:  pkgconfig(zlib)
Provides:       MediaInfo = 0.7.7.8
Obsoletes:      MediaInfo < 0.7.7.8

%description
MediaInfo supplies technical and tag information about a video or
audio file.

It reads the following information:
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

It supports the following containers/codecs:
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

%package gui
Summary:        GUI for mediainfo
Group:          Productivity/Multimedia/Other
Provides:       MediaInfo-gui = 0.7.7.8
Obsoletes:      MediaInfo-gui < 0.7.7.8

%description gui
This package contains a Frontend for mediainfo.

MediaInfo supplies technical and tag information about a video or
audio file.

%package -n kf5-mediainfo
Summary:        KF5 extension for mediainfo-gui
Group:          Productivity/Multimedia/Other
Requires:       %{name}-gui
Obsoletes:      kde4-%{name} < %{version}
Provides:       kde4-%{name} = %{version}

%description -n kf5-mediainfo
KF5 context menu extension for mediainfo-gui.

%prep
%setup -q -n MediaInfo
sed -i 's/\r$//' *.html *.txt Release/*.txt
chmod 0644 *.html *.txt Release/*.txt

%build
# build CLI
pushd Project/GNU/CLI
    autoreconf -fiv
    %configure
    make %{?_smp_mflags}
popd

# now build GUI
pushd Project/GNU/GUI
    autoreconf -fiv
    %configure
    make %{?_smp_mflags}
popd

%install
pushd Project/GNU/CLI
%make_install
popd

pushd Project/GNU/GUI
%make_install
popd

# icon
install -dm 755 %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
install -m 644 Source/Resource/Image/MediaInfo.png \
    %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
install -dm 755 %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -m 644 Source/Resource/Image/MediaInfo.svg \
   %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -dm 755 %{buildroot}%{_datadir}/pixmaps
install -m 644 Source/Resource/Image/MediaInfo.png \
    %{buildroot}%{_datadir}/pixmaps/mediainfo-gui.png

rm %{buildroot}%{_datadir}/kde4/services/ServiceMenus/mediainfo-gui.desktop
%suse_update_desktop_file -n %{name}-gui AudioVideo AudioVideoEditing

# these files are just ridicully large:
gzip -n -9 License.html
gzip -n -9 History_*.txt
%fdupes -s %{buildroot}/%{_datadir}

%files
%defattr(-,root,root,-)
%doc Release/ReadMe_CLI_Linux.txt
%doc License.html.gz History_CLI.txt.gz
%{_bindir}/mediainfo

%files gui
%license License.html.gz
%doc Release/ReadMe_GUI_Linux.txt History_GUI.txt.gz
%{_bindir}/mediainfo-gui
%dir %{_datadir}/metainfo
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/pixmaps/*.xpm
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/apps/*.svg
%{_datadir}/metainfo/mediainfo-gui.metainfo.xml

%files -n kf5-mediainfo
%dir %{_kf5_servicesdir}
%dir %{_kf5_servicesdir}/ServiceMenus
%dir %{_datadir}/apps
%dir %{_datadir}/apps/konqueror
%dir %{_datadir}/apps/konqueror/servicemenus
%{_datadir}/apps/konqueror/servicemenus/*.desktop
%{_kf5_servicesdir}/ServiceMenus/*.desktop

%changelog
* Fri Sep  4 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 20.08
  Added:
  * MPEG-H 3D Audio full featured support (group presets, switch
    groups, groups, signal groups)
  * MP4/MOV: support of more metadata locations
  * JSON and XML outputs: authorize "complete" output
  * MPEG-4: support of TrueHD
  * WM: show legacy value of performer if not same as modern one
  * WAV: trace of adtl (Associated Data List) chunk
  Fixed:
  * URL encoding detection fix for URL having a query part
    (issue with e.g. pre-signed AWS S3 URLs)
  * Don't try to seek to the end (false positive range related
    error with HTTP)
  * DPX: don't load the whole file in RAM
  * Opus: fix wrong channel mapping
  * Miscellaneous other bug fixes
  version 20.03
  Added features:
  * AC-4 full featured support (presentations, groups,
    substreams)
  * MPEG-H 3D Audio basic support
  * MPEG-TS: audio preselection descriptor support
  * Dolby Vision v2 detection
  * MPEG-4: support of colr/nclx (color information) box
  Bugs fixed:
  * URL encoding option fixes, permitting to use URL encoded or
    non URL encoded links
  * AAC: fix SBR frequency when in ADIF
  * DPX: ColorimetricSpecification and TransferCharacteristic
    were inverted
  * Several crash and memory leaks fixes
  version 19.09
  Added:
  * AC-4: basic detection, raw, in MP4 or TS
  * AC-3/E-AC-3: display time code of the first frame
  * Don't show anymore by default "encoded" bit rates and stream
    sizes
  * MOV: Decode more language codes
  Corrections:
  * MXF: some metadata were missing
  * AC-3: AC-3 actually has no bit depth, removing the default
    16 value
  * AC-3/E-AC-3: fix bitrate info (so duration) with streams
    having a time code
  * AC-3: parse more frames also when in MP4, in order to better
    detect JOC (Atmos)
  * MP4: do not show audio bit depth if it is the "default" 16
    (value is not trustable enough)
  * ProRes RAW: we know only width and height
  * SubRip: bad handling of files having a quote character
  version 19.07
  Added:
  * Dolby E: readout of Dolby E program description
  * MXF: Detection of Dolby Vision
  * MP4: support of Spatial Audio Metadata
  * DV: color space is explicit
  * DV: audio format settings
  * Matroska: PCM bit rate
  * MOV, MXF: Time code frame rate
  * DV: DVCAM commercial name for locked audio and PAL 4:2:0
  * MXF: Time code track name
  Corrected:
  * USAC: frame rate was missing in case of non standard
    sampling rate
  * USAC: fix infinite loop with some LATM streams
  * WAV: MP3 delay should be added to BWF time reference
  * TTML: fix wrong output with standalone files
  * N19/STL: fix crash with some uncommon framerates
  * VC-3: fix sub sampling with some v2 files
  * DV: Time code frame number was wrong (divided by 2) for
    50/60 fps content
  version 19.04
  Added:
  * USAC: DRC effect types, Sample peak level, True peak level,
    Program loudness
  * HDR: SMPTE ST 2094 App 4 (including HDR10+) support
  * HDR: move HDR10, Dolby Vision and SL-HDR meta to specific
    generic "HDR Format" lines
  * Matroska: SMPTE ST 2086 (HDR10) support
  * Matroska: FieldOrder support
  * HEIF image format support
  * AV1: support of AV1 in MP4, HEIF, IVF
  * MOV: Add a lot more countries to AppleStoreCountry field
    internal list
  * MXF: Fix memory leak when fully parsing big file with
    acquisition metadata
  * HEVC: more HEVC profiles (Multiview, Scalable, Screen
    Content...)
  * AAC: better handling of corrupted streams
  * AAC: better handling of unknown channel layouts
  * AVC in MP4: better support of corrupted streams
  Changed:
  * B1101, AVI: fix crash with some invalid streams
  * B1101, SMPTE ST 337: fix crash with some invalid streams
  * Matroska: chapters timestamp were not display if chapters
    have no name
  * MXF: Fix false positive truncated file detection when there
    is no Random Index Pack
  * AAC: channel layout typos (Rls instead of Lrs, Lr instead of
    Rb)
  * ProRes: correctly show color space if alpha plane is present
  * MPEG Audio: some VBR files use "Info" Xing header, so we
    ignore the  difference between "Info" and "Xing"
  * I943, MPEG-4: wrong display aspect ratio in some corner
    cases (32-bit release only)
  * I1096, OGG: assign METADATA_BLOCK_PICTURE tag to cover
  version 18.12
  Added features:
  * DCP: support of multi-reel packages
  * EBUCore: added some FFV1 related metadata
  * JPEG: better info display of CYMK files
  * Provide source of the color related metadata (container or
    stream) (hidden by default)
  * MXF: display more information when wrapper/essence values
    are detected as not same
  * MXF: ProRes profiles
  * MPEG-4: ProRes RAW support
  * MPEG-TS: add support of parsing some ETSI TS 103-433 messages
  Bug fixes:
  * MPEG-2 Video: variable GOP detection fix
  * MPEG-7 export: some fields were missing due to the removal
    of some legacy fields
  * ADTS: Fix display of channel count for 8-channel streams
  * ID3v2: fix some date related issues
  * I298, ID3v2: fix wrong read of recording date in some cases
  * I1032, PBCore2: fix essenceFrameSize with non Video tracks
  * I1096, JPEG: fix crash with one file
  * Several other crash and memory leak fixes
  version 18.08.1
  * Fix XML/MPEG-7/PBCore2 output discarding non ANSI characters
  version 18.08
  Added features:
  * Dolby Atmos (in E-AC-3 or TrueHD): support of bed channel
    count/configuration + objects count + complexity index
  * AC-3/DTS/AAC: display of info about legacy decoders behavior
    removed
  * AC-3/DTS/AAC: some changes in how format is displayed
  * AC-3/DTS/AAC: better split between technical names and
    commercial names
  * AAC: support of profile information from MP4_IOD_Tag
    AudioProfileLevelIndication
  * USAC (xHE-AAC) support
  * Audio channel layout: using a new terminology, better suited
    for 3D Audio, see https://mediaarea.net/AudioChannelLayout
  * DSD (DSF & DSDIFF) support
  * DXD (Digital eXtreme Definition) commercial name
  * Dolby Vision: use new form for profile (numbers instead of
    acronyms)
  * New format "Directory" when image sequence + audio file is
    detected (1 directory style for the moment)
  * PBCore2 export update, thanks to WGBH
  * MPEG-7 export update
  * NISO export update
  * AV1: support of AOmedia AV1 based on 1.0.0 specifications
  * ATRAC9 detection
  * Versionned RPMs
  * HEVC: better support of buggy SEI
  * ADTS: CodecID
  * Support of injection of external metadata
  * HTTPS: support of AWS extension "x-amz-*" in HTTPS headers,
    permitting to manage temporary credentials (AssumeRole)
  * MPEG-4, #1005: Obey edit list in QuickTime Timecode track
  Bug corrections:
  * MIXML: hide fields which were hidden in normal output
  * Hybrid AC-3/E-AC-3 (in Blu-rays): bit rate info was wrong
  * Lot of bug fixes, see full log for more info
  version 18.05
  Added:
  * PBCore 2.1 export update, sponsored by WGBH as part of the
    NEH-funded PBCore Development and Preservation Project
  * TIFF: more IFDs are supported (density, software...)
  * NISO Z39.87 output
  Fixed:
  * Mastering Display Color Primaries: was always showing BT.709
    instead of real value, when present
  * Attachments: do not provide anymore attachments content in XML
    by default, fixes
- Use nominal phrase for summaries
* Tue Mar 20 2018 aloisio@gmx.com
- Update to version 18.03
  added:
  * AV1: support of AOmedia AV1 based on latest specifications
    draft, raw (OBU) and in MKV
  * MXF: HDR metadata support
  * MXF: detection and parsing of ProRes (SMPTE RDD 44)
  * MXF: framerate container/stream incoherence detection
  * DPX: endianess, packing mode, compression mode
  * AVC: add consumer camera recording date/time
  * AVC: add consumer camera model name and iris F number
  * JPEG: ICC parsing, display of ICC color space
  * EBUCore: possibility to inject external metadata in the output
    from MediaInfo
  * JSON output
  * Attachments: do not provide anymore attachments content in XML
    by default, reducing XML output size
  fixed:
  * colour description: trying (again!) to have more coherent
    labeling
  * DCP/IMF: fix crash with some CPL files
  * I782, FFV1: Golomb Rice parsing was wrong
  * I210, FFV1: remove sar_den test must be 0 if sar_num is 0
  * AAC: SBR parsing issue with 3+ channel streams, with sometimes
    false-positive PS detection
  * BMP: was wrongly considering 4-bit without palette as with
    palette so  wrong bit depth
  * DPX: some elements in trace were wrongly displayed (wrong
    endianess)
  * B1082, Ancillary data: fix infinite loop
* Thu Dec 21 2017 aloisio@gmx.com
- Update to version 17.12
  * MediaInfoOnline: https://mediaarea.net/MediaInfoOnline
  * JavaScript build and example
  * Dolby Vision: detection of Dolby Vision and display of profile
    for MPEG-TS and MP4 files
  * MPEG-4: Support of external time code tracks (.qtc)
  * JPEG 2000: Support of IMF profiles
  * F523, BDMV: Support of UHD Blu-ray playlist
  * Endianness and Sign report for PCM Matroska tracks
  * MPEG-4: Resolume DXV display
  * MPEG-4: support of file names >64 chars long or non ASCII for
    referenced files
  * Slight binary size optimizations
  * colour_description: some changes in order to have more
    readable names (DCI P3, Display P3, sRGB)
  * MP4: crash with some HEVC streams with Dolby Vision
  * VC-3: frame rate should not be detected as wrong when there
    are several frames per block
  * Matroska: wrong color range info
  * Matroska: fix crash with some corrupted files
  * MXF: better support of height when there is an incoherence
    between header and footer
  * transfer_characteristics: fix BT.2020 difference between
    values 14 and 15
  * Trace: fix freeze with some files
  * Trace: invalid character encoding with some MOV files
  * Some memory leak fixes
- New source URL
- Dropped kde4 subpackage
- Spec cleanup
* Thu Nov  2 2017 aloisio@gmx.com
- Update to version 17.10
  * Version scheme is now YY.MM (year dot month, 2 digits each)
  * New MediaInfo XML output, with XSD, more suitable for
    automatic parsing. Use " --Output=OLDXML" for keeping previous
    behavior
  * New " --Info_OutputFormats" option for listing supported
    output formats
  * Universal Ad ID: refactored display, better display of value
    and registry, XML name slightly modified
  * MOV: support of HDR metadata (MasteringDisplayColorVolume,
    MaxCLL, MaxFALL)
  * BWF: display of UMID and loudness info
  * AAC: show program_config_element in trace
  * MPEG Audio: frame rate info
  * PCM in WAV and Matroska: Support of ValidBitsPerSample
  * I197, EBUCore: 1.8 output uses now final version of XSD and
    final XSD location
  * Matroska: tweaking frame rate empirical detection for some
    corner cases
  * I1070, LAME 3.100 info tag was incorrectly parsed
  * B1068, MPEG Audio: Incoherent duration between General and
    Audio parts, Audio part duration fixed
  * Matroska: showing "A_MS/ACM" Matroska CodecID
  * MXF: Fix crash with some buggy files
  * MXF: was not well supporting MXF referencing only 1 file
  * PCM in WAV: 8-bit content is unsigned and without endianess
  * PCM in WAV and Matroska: More coherency between Wave info
    and ExtensibleWave Info (bitdepth, sign)
  * WAV: GUID display was with first 8 bytes in wrong order
  * Several crash fixes
* Mon Sep 11 2017 aloisio@gmx.com
- Update to version 0.7.99
  * EBUCore: JSON output
  * EBUCore: add writingLibraryName and writingLibraryVersion
    attributes
  * Ad-ID identifier display on a single line ("Value
    (Registry)" format)
  * MPEG-4: Better display of format of VobSub tracks
  * MPEG-4: CodecID is stsd name + ObjectTypeId for mp4a, mp4v,
    mp4s
  * AVC: preferred_transfer_characteristics support
  * MPEG Video, MPEG-4 Visual, AVC, HEVC, MPEG-4, Matroska:
    correct detection of RGB
  * matrix_coefficients: detection of Y'D'zD'x and
    Chromaticity-derived
  * AAC: info about SBR/PS being implicit/explicit/NBC (Not
    Backward Compatible)
  * AAC: indicate audioObjectType in CodecID
  * Fix a weird 1.334 DAR due to a rounding issue
* Wed Aug  9 2017 aloisio@gmx.com
- Update to version 0.7.98
  * Matroska: handling of files with Tracks element after Cluster
    elements
  * Matroska: detection of Duration tag alone and use it even if
    tag writing date is not there.
  * Matroska: mapping of colour description elements, timecode and
    handler name to corresponding MediaInfo fields
  * I169, WAV: too much aggressive detection of wrong 5-channel
    audio, now limited on AC-3 and DTS
  * transfer_characteristics and matrix_coefficients slight change
    in order to have them unique per ISO integer value
  * EBUCore: All XML elements are correctly escaped
  * PBCore: All XML elements are correctly escaped
* Fri Jun 30 2017 aloisio@gmx.com
- Update to version 0.7.97
  * HEVC: support of stream having VPS hrd_parameters
  * FLV: support of FLV files with an ID3v2 header
  * FLV: detect some incoherent frame rates in buggy files
  * TIFF: support of more tags
  * I518, AAC: consider 4 back channels as 2 side + 2 back channels
  * Matroska: integrate all elements from Matroska specs in
    MediaTrace
  * WAV: parsing of MPEG Audio extension "mext" chunk and
    displayed in MediaTrace
  * MPC: channels count
  * AAC: ADTS/ADIF duration in case of full parsing and/or "risky
    bitrate estimation" option
  * MXF: less false-positive detection of some files as MXF
  * B1053, WAV: metadata coherency, ignore "fact" chunk more often
    in order to avoid bad information when this chunk is buggy
  * B1029, DPX: DPX endianess not considered with some fields in
    MediaTrace
  * Custom template: can check "Other" part as any other parts
  * Matroska: fix parsing issue with small byte blocks are taken
    from the file e.g. when reading from HTTP link
  * Matroska: files with unknown block size were flagged as
    truncated
  * MediaTrace: values with a \n were breaking the text report
    lines
  * Some typos (RefFrames, SPF)
* Thu Jun  1 2017 aloisio@gmx.com
- Update to version 0.7.96
  * Chinese (Simplified) translation updated
  * MPEG-4: display of recorded date from DV substream
  * Disabling web link as they are too much outdated
  * I505, AC-3: crash with some potentially malformed frames
  * I477, AVC: fix hang when open .mpls from some 3D BD
  * MPEG-4: does not show "1904" year is raw value is 0 (Mac/Linux)
  * Dedicated read thread disabled by default (rare dead locks)
  * #B1027, MPEG-TS: some files where detected as MPEG-TS or BDAV
    but they aren't
  * Sequence of files : frame count was wrong with sequence of
    MPEG-TS files (was count of files)
  * MXF: detection of more 608/708 with parsing of few frames in the
    middle of the file was broken
* Fri May  5 2017 aloisio@gmx.com
- Update to version 0.7.95
  * EBUCore: EBUCore 1.8 with acquisition metadata output.
  * Better support of growing files, especially when accessed by FTP
  * Matroska: better support of some broken files (high
    EBMLMaxSizeLength, padding before start of EBML)
  * EXR: showing Multipart and Deep flags
  * EXR: show image compression method
  * EBUCore: fixed display aspect ratio (was using rational)
  * EBUCore: fixed frame rate factor (was num/den instead of factor)
  * AVC: some streams with dynamic frame type were having a wrong
    frame rate
  * MPEG-4: some old AAC tracks were not correctly detected
  * Matroska: was sometimes displaying "Bit depth: Bit0" when bit
    depth is unknown
  * Nut: fix crash with some files
  * FFV1: PixelAspectRatio was an integer, switched to 3-digit
    rational
  * DTS: fix frame count
  * Dolby E: fix frame count
  * EBUCore: fix regression creating invalid XML files
  * AVC: some streams with dynamic frame type were having a wrong
    frame rate
* Sun Apr 30 2017 bwiedemann@suse.com
- call gzip -n to make build fully reproducible
* Thu Mar 30 2017 aloisio@gmx.com
- Update to version 0.7.94
  * VC-3: detection of embedded time code + VC-3: better
    support of stream with width 960 or 1440
  * VC-3: support of version 3 (a.k.a. DNxHR), including
    profile and level for version 1/2 (a.k.a. DNxHD)
  * Matroska trace feature: reduction of its size
  * MXF trace feature: reduction of its size
  * M143, MXF with Acquisition Metadata: crash fixed
  * Several crash fixes
  0.7.94
  * Matroska: detection of native FFV1 CodecID ("V_FFV1") +
    AC-3/E-AC-3: detection of Atmos inside core streams
  * AC-3/E-AC-3: slight reorganization of metadata display for
    dual mono and surround
  * AC-3/E-AC-3: "complete main" and similar info moved to
    "Service kind" dedicated line
  * AC-3/E-AC-3: more precision about how is built a stream
    (e.g. "E-AC-3+Atmos / E-AC-3" or "TrueHD+Atmos / TrueHD /
    AC-3")
  * WTV: basic detection
  * MPEG-TS: Detection of Opus
  * URL: "URLEncode" option for saying if the input should be
    URL encoded or not (default is guess = no change except if
    it contains spaces)
  * MediaTrace: for bitstreams (not bytestreams), bit offset
    was wrong
  * HLS: duration was sometimes wrong, reading only the first
    TS file duration. Now full duration is displayed
  * MPEG-TS: if stream is encrypted or invalid, level was
    sometimes not the expected one for AVC (e.g. "BaseLine@3.0"
    instead of "Baseline@3")
  * Matroska: FFV1 stream width/height was not initialized
    when Matroska track header width/height is after CodecID
  * FFV1: fix potential crash with some buggy slice headers
  * Matroska: crash in case of big attachment and CRC32 present
* Sat Mar  4 2017 jengelh@inai.de
- Trim description, avoid rhetorical questions.
- Drop export CFLAGS.. this is already done by %%configure.
* Sun Feb 26 2017 aloisio@gmx.com
- Update to version 0.7.92.1
  * Fix a performance regression in the matroska parser
  version 0.7.92
  New features:
  * #F507, MXF: detection of HLG Transfer Characteristic
  * #F508, HEVC: support of preferred_transfer_characteristics
    SEI (from HEVC/H.265 draft, preferred method for HLG in DVB)
  * MXF: parsing of AVC descriptors and crosscheck with the
    essence content
  * MP4: more AppleStoreCountry values mapped to countries, show
    the country number if unknown
  * File extension: test if the file extension correspond to the
    container format
  * AVI/WAV: test of truncated file
  * MIXML output: Format_Profile divided in Format_Profile,
    Format_Level, Format_Tier
  * ID3v2: TCAP tag is mapped to new field "PodcastCategory"
  Bug fixes:
  * MIXML output: some *_Original values were missing
  * MXF/Teletext: was not correctly detecting non subtitle
    streams
  * ID3v2: TP2 tag was incorrectly mapped to "Accompaniment",
    now mapped to "Album_Performer"
  * ID3v2: TSO2 tag was incorrectly mapped to "Performer_Sort",
    now mapped to "Album_Performer_Sort"
  * ID3v2: TCMP tag was displayed twice (2 "Compilation" lines)
  * Windows version was sometimes showing a long character
    string in Windows explorer, changed to a shorter character
    string
  version 0.7.91
  New features:
  * Add TIFF extension to Windows shell extension
  * IMF and PTX: more languages detected from file names (but
    the full list of common languages tags still need to be added)
  * IMF and PTX: support of non-standard but common "LAS" =
    "Spanish (Latin America)" language code
  * MXF: Support of color primaries, transfer characteristic,
    coding equations defined in SMPTE ST 2067-21:2016 e.g. xvYCC
    or BT.2020
  * Minor performance optimizations and cleanup (Thanks to Pavel
    Pimenov)
  * MediaTrace optimization for Matroska
  Bug fixes:
  * Fixed parsing of FFV1 v0/v1
  * PTX: fix crash due to bad parsing of some file names while
    looking for track language
  version 0.7.90
  New features:
  * #M94, WAV: support of file with a buggy RIFF header
  * Matroska: detection of segment size of zero (compatibility
    risks e.g. Windows 10 Media Player does not play such file)
  * MXF: detection of some incoherences between header and footer
  * MXF: display of Locked information
  * N19/STL: support of 48/50/60 fps content
  * N19/STL: display of time code of first frame
  * AC-3: bit depth
  * MPEG Video: CBR bitrate mode information based on vbv_delay
  * DXW: support of fake time code attribute
  Bug fixes:
  * Teletext in MPEG-TS: CodecID, format (classic teletext or
    subtitle), video delay were sometimes not displayed
  * PDF: fixed crash with some files with full analysis set
  * #B485, BMP height is negative
  * Several minor fixes
- Dropped mediainfo-rpmlintrc
* Thu Oct  6 2016 aloisio@gmx.com
- Update to version 0.7.89
  * too many changes to list, see included History_*.txt
- Added kf5-mediainfo
- Spec cleanup
* Thu Mar 27 2014 i@margueirte.su
- update version 0.7.67
  * MXF: duplicate display of some time code streams in ancillary data
  * B814, AAC: Wrong detection of audioObjectType==29
* Thu Feb 28 2013 fisiu@opensuse.org
- update to 0.7.62
  * see History_CLI.txt and History_GUI.txt for details.
* Thu Oct  4 2012 i@marguerite.su  
- update to 0.7.60
  * see History_CLI.txt and History_GUI.txt for details.
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to BuildRequires to fix >12.1 build
* Mon Oct 24 2011 pascal.bleser@opensuse.org
- update to 0.7.50
* Wed Mar  9 2011 pascal.bleser@opensuse.org
- update to 0.7.42
* Sat Nov 13 2010 pascal.bleser@opensuse.org
- update to 0.7.36
* Sun Sep 19 2010 pascal.bleser@opensuse.org
- update to 0.7.35
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.7.34
* Mon May  3 2010 toni@links2linux.de
- update to 0.7.32
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.7.31
* Fri Mar 26 2010 toni@links2linux.de
- update to 0.7.30
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.7.29
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.7.28
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.7.27
* Wed Dec 23 2009 toni@links2linux.de
- update to 0.7.26
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.7.25
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.7.24
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.7.23
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.7.19
* Mon Jun 22 2009 toni@links2linux.de
- update to 0.7.17
* Wed May 20 2009 toni@links2linux.de
- update to 0.7.16
* Thu Apr 30 2009 toni@links2linux.de
- update to 0.7.15
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.7.14
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.7.13
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.7.12
* Fri Apr  3 2009 toni@links2linux.de
- update to 0.7.13
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.7.12
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.7.11
- added sub-package kde4-mediainfo
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.7.10
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.7.9
* Wed Dec 10 2008 toni@links2linux.de
- added defattr in subpackage konqueror
- corrected icon-name for desktop-entry
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.7.8
- added sub-package for konqueror extension
* Tue Nov 18 2008 toni@links2linux.de
- changed package layout, reflecting new upstream tar-balls
- rebuild using libzen(-devel) and libmediainfo(-devel)
- renamed package to mediainfo (obsoletes MediaInfo)
- added subpackage gui (obsoletes MediaInfo-gui)
- using desktop file from tarball (includes french localisation)
* Mon Nov 10 2008 toni@links2linux.de
- update to 0.7.7.8
* Fri Oct 17 2008 toni@links2linux.de
- update to 0.7.7.7
* Fri Sep 12 2008 toni@links2linux.de
- update to 0.7.7.6
* Fri Aug 22 2008 toni@links2linux.de
- update to 0.7.7.5
* Fri Jul 11 2008 toni@links2linux.de
- update to 0.7.7.4
* Thu Jun 26 2008 toni@links2linux.de
- update to 0.7.7.3
* Fri Jun 13 2008 toni@links2linux.de
- update to 0.7.7.2
* Fri May 30 2008 toni@links2linux.de
- update to 0.7.7.1
* Fri May 16 2008 toni@links2linux.de
- update to 0.7.7.0
* Mon Apr 28 2008 toni@links2linux.de
- update to 0.7.6.4
* Sat Apr 12 2008 toni@links2linux.de
- update to 0.7.6.3
* Fri Mar 28 2008 toni@links2linux.de
- update to 0.7.6.2
* Fri Mar 14 2008 toni@links2linux.de
- update to 0.7.6.1
* Fri Feb 29 2008 toni@links2linux.de
- update to 0.7.6.0
* Fri Feb  8 2008 toni@links2linux.de
- update to 0.7.5.9
* Fri Feb  1 2008 toni@links2linux.de
- update to 0.7.5.8
* Wed Jan  9 2008 toni@links2linux.de
- update to 0.7.5.7
* Mon Dec 10 2007 toni@links2linux.de
- update to 0.7.5.6
* Fri Nov  9 2007 toni@links2linux.de
- update to 0.7.5.5
- libMatroska and libEbml are no more used
- The script now look for /usr/lib/libz.a and /usr/include/zlib.h before
  downloading at the official zlib website.
  - -> If you have the development package of zlib, no more downloads!
* Sat Nov  3 2007 toni@links2linux.de
- update to 0.7.5.4
* Fri Nov  2 2007 toni@links2linux.de
- initial build 0.7.5.3
